<?php
// Version: 1.1.5; index

/*	This template is, perhaps, the most important template in the theme. It
	contains the main template layer that displays the header and footer of
	the forum, namely with main_above and main_below. It also contains the
	menu sub template, which appropriately displays the menu; the init sub
	template, which is there to set the theme up; (init can be missing.) and
	the linktree sub template, which sorts out the link tree.

	The init sub template should load any data and set any hardcoded options.

	The main_above sub template is what is shown above the main content, and
	should contain anything that should be shown up there.

	The main_below sub template, conversely, is shown after the main content.
	It should probably contain the copyright statement and some other things.

	The linktree sub template should display the link tree, using the data
	in the $context['linktree'] variable.

	The menu sub template should display all the relevant buttons the user
	wants and or needs.

	For more information on the templating system, please see the site at:
	http://www.simplemachines.org/
*/

// Initialize the template... mainly little settings.
function template_init()
{
	global $context, $settings, $options, $txt;
	
        if(!$context['user']['is_guest'] && isset($_POST['options']['theme_color']))
        {
           include_once($GLOBALS['sourcedir'] . '/Profile.php');
           makeThemeChanges($context['user']['id'], $settings['theme_id']);
           $options['theme_color'] = $_POST['options']['theme_color'];
        }

	/* Use images from default theme when using templates from the default theme?
		if this is 'always', images from the default theme will be used.
		if this is 'defaults', images from the default theme will only be used with default templates.
		if this is 'never' or isn't set at all, images from the default theme will not be used. */
	$settings['use_default_images'] = 'never';

	/* What document type definition is being used? (for font size and other issues.)
		'xhtml' for an XHTML 1.0 document type definition.
		'html' for an HTML 4.01 document type definition. */
	$settings['doctype'] = 'xhtml';

	/* The version this template/theme is for.
		This should probably be the version of SMF it was created for. */
	$settings['theme_version'] = '1.1';

	/* Set a setting that tells the theme that it can render the tabs. */
	$settings['use_tabs'] = !empty($settings['modbutton']) ? $settings['modbutton'] : true;

	/* Use plain buttons - as oppossed to text buttons? */
	$settings['use_buttons'] = !empty($settings['modbutton']) ? $settings['modbutton'] : true;

	/* Show sticky and lock status seperate from topic icons? */
	$settings['seperate_sticky_lock'] = true;
	
  // Lets load our additional crap.
  loadLanguage('ThemeStrings');
}

// The main sub template above the content.
function template_main_above()
{
	global $context, $settings, $options, $scripturl, $txt, $modSettings;
        
        // Lets get the Theme Selector started, England is the forced default that'll load when no custom default is set in Currrent Theme.
        if (isset($options['theme_color'])) 
        $mycolor = $options['theme_color'];
        else
        {
           // Defaults.
           $options['theme_color'] = isset($settings['default_theme_color']) ? $settings['default_theme_color'] : 'england';
           $mycolor=$options['theme_color'];
        }

	// Show right to left and the character set for ease of translating.
	echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"', $context['right_to_left'] ? ' dir="rtl"' : '', '><head>
	<meta http-equiv="Content-Type" content="text/html; charset=', $context['character_set'], '" />
	<meta name="description" content="', $context['page_title'], '" />', empty($context['robot_no_index']) ? '' : '
	<meta name="robots" content="noindex" />', '
	<meta name="keywords" content="' , !empty($settings['meta']) ? $settings['meta'] : 'PHP, MySQL, bulletin, board, free, open, source, smf, simple, machines, forum' , '" />' , !empty($settings['favion']) ? '' : '
        <link rel="shortcut icon" href="' . $settings['favicon'] . '" />' , '
	<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/script.js?fin11"></script>
	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var smf_theme_url = "', $settings['theme_url'], '";
		var smf_images_url = "', $settings['images_url'], '";
		var smf_scripturl = "', $scripturl, '";
		var smf_iso_case_folding = ', $context['server']['iso_case_folding'] ? 'true' : 'false', ';
		var smf_charset = "', $context['character_set'], '";
	// ]]></script>
	<title>', $context['page_title'], '</title>';

	// The ?fin11 part of this link is just here to make sure browsers don't cache it wrongly.
	echo '
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style/guestbar.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style/style.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style/dropmenu.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['theme_url'], '/style/' . $mycolor . '_style.css?fin11" />
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/print.css?fin11" media="print" />';
	
	// Lets load the dropdown file
	echo'
        <script type="text/javascript" src="', $settings['theme_url'], '/js/drop.js"></script>';

	/* Internet Explorer 4/5 and Opera 6 just don't do font sizes properly. (they are big...)
		Thus, in Internet Explorer 4, 5, and Opera 6 this will show fonts one size smaller than usual.
		Note that this is affected by whether IE 6 is in standards compliance mode.. if not, it will also be big.
		Standards compliance mode happens when you use xhtml... */
	if ($context['browser']['needs_size_fix'])
		echo '
	<link rel="stylesheet" type="text/css" href="', $settings['default_theme_url'], '/fonts-compat.css" />';

	// Show all the relative links, such as help, search, contents, and the like.
	echo '
	<link rel="help" href="', $scripturl, '?action=help" target="_blank" />
	<link rel="search" href="' . $scripturl . '?action=search" />
	<link rel="contents" href="', $scripturl, '" />';

	// If RSS feeds are enabled, advertise the presence of one.
	if (!empty($modSettings['xmlnews_enable']))
		echo '
	<link rel="alternate" type="application/rss+xml" title="', $context['forum_name'], ' - RSS" href="', $scripturl, '?type=rss;action=.xml" />';

	// If we're viewing a topic, these should be the previous and next topics, respectively.
	if (!empty($context['current_topic']))
		echo '
	<link rel="prev" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=prev" />
	<link rel="next" href="', $scripturl, '?topic=', $context['current_topic'], '.0;prev_next=next" />';

	// If we're in a board, or a topic for that matter, the index will be the board's index.
	if (!empty($context['current_board']))
		echo '
	<link rel="index" href="' . $scripturl . '?board=' . $context['current_board'] . '.0" />';

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);
		
	// and the fontsise
	if ($context['user']['is_guest'])
		$options['myfontsize'] = !empty($_COOKIE['myfontsize']) ? $_COOKIE['myfontsize'] : '90';

	// set fontsize from user choice
	echo '
	<style type="text/css">
		#mainframe
		{
			font-size: ' , !empty($options['myfontsize']) ? $options['myfontsize'] : '90', '%;
		}
	</style>';
	
	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'];

	// We'll have to use the cookie to remember the header...
	if ($context['user']['is_guest'])
		$options['collapse_header'] = !empty($_COOKIE['upshrink']);

	// Output any remaining HTML headers. (from mods, maybe?)
	echo $context['html_headers'], '

	<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
		var current_header = ', empty($options['collapse_header']) ? 'false' : 'true', ';

		function shrinkHeader(mode)
		{';

	// Guests don't have theme options!!
	if ($context['user']['is_guest'])
		echo '
			document.cookie = "upshrink=" + (mode ? 1 : 0);';
	else
		echo '
			smf_setThemeOption("collapse_header", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
			document.getElementById("upshrink").src = smf_images_url + (mode ? "/upshrink2.gif" : "/upshrink.gif");

			document.getElementById("upshrinkHeader").style.display = mode ? "none" : "";
			document.getElementById("upshrinkHeader2").style.display = mode ? "none" : "";

			current_header = mode;
		}
	// ]]></script>';

	// the routine for the info center upshrink
	echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			var current_header_ic = ', empty($options['collapse_header_ic']) ? 'false' : 'true', ';

			function shrinkHeaderIC(mode)
			{';

	if ($context['user']['is_guest'])
		echo '
				document.cookie = "upshrinkIC=" + (mode ? 1 : 0);';
	else
		echo '
				smf_setThemeOption("collapse_header_ic", mode ? 1 : 0, null, "', $context['session_id'], '");';

	echo '
				document.getElementById("upshrink_ic").src = smf_images_url + (mode ? "/expand.gif" : "/collapse.gif");

				document.getElementById("upshrinkHeaderIC").style.display = mode ? "none" : "";

				current_header_ic = mode;
			}
		// ]]></script>
</head>
<body>';
      
// This is for the Register Bar
if($settings['regbar'] == 1 && $context['user']['is_guest'] && !$context['current_action'] == 'register')
{
   echo'
   <div id="infobar">
            <a href="' , $scripturl , '?action=register">' , !empty($settings['regbar_msg']) ? $settings['regbar_msg'] : $txt['regbar1'], '</a>
   </div>';
}
      
      echo'
<table width="' , (!empty($settings['width'])) ? $settings['width'] : '800' , '" border="0" cellspacing="0" cellpadding="0" align="center" class="normal">
  <tr>
    <td>
	<div ', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' style="width: 100%;"' : '', '>
		<table cellpadding="0" cellspacing="0" border="0" width="100%">
			<tr>
				<td class="topper" valign="bottom" align="center">
				' , template_menu() , '
				</td>
			</tr>
		</table>
        </div>';
                
                
        // display user name
	echo '
		<table width="100%" cellpadding="0" cellspacing="0" border="0" >
			<tr>';

	if($context['user']['is_logged'])
		echo '
				<td class="titlebg2" height="32">
					<span style="font-size: 130%;"> ', $txt['hello_member_ndt'], ' <b>', $context['user']['name'] , '</b></span>
				</td>';

	// display the time
	echo '
				<td class="titlebg2" height="32" align="right">
					<span class="smalltext">' , $context['current_time'], '</span>';

	// this is the upshrink button for the user info section
	echo '
					<a href="#" onclick="shrinkHeader(!current_header); return false;"><img id="upshrink" src="', $settings['images_url'], '/', empty($options['collapse_header']) ? 'upshrink.gif' : 'upshrink2.gif', '" alt="*" title="', $txt['upshrink_description'], '" align="bottom" style="margin: 0 1ex;" /></a>
				</td>
			</tr>
			<tr id="upshrinkHeader"', empty($options['collapse_header']) ? '' : ' style="display: none;"', '>
				<td valign="top" colspan="2">
					<table width="100%" class="bordercolor" cellpadding="8" cellspacing="1" border="0" style="margin-top: 1px;">
						<tr>';
                                                      if (!empty($context['user']['avatar']))
	                                              {
                                                        echo '
							<td class="windowbg" valign="middle">', $context['user']['avatar']['image'], '</td>';
	                                              }
	                                              elseif(empty($context['user']['avatar']) && $settings['defaultav'] == 1 && $context['user']['is_logged'])
	                                              {
                                                        echo '
							<td class="windowbg" valign="middle"><img src="' , $settings['images_url'] , '/no-avatar.gif" alt="" /></td>';
	                                              }
	                                              echo'
							<td colspan="2" width="100%" valign="top" class="windowbg2"><span class="middletext">';
	

	// If the user is logged in, display stuff like their name, new messages, etc.
	if ($context['user']['is_logged'])
	{
		echo '
								<a href="', $scripturl, '?action=unread">', $txt['unread_since_visit'], '</a> <br />
								<a href="', $scripturl, '?action=unreadreplies">', $txt['show_unread_replies'], '</a><br />';

	}
	// Otherwise they're a guest - send them a lovely greeting...
	else
		echo $txt['welcome_guest'];

	// Now, onto our second set of info, are they logged in again?
	if ($context['user']['is_logged'])
	{
		// Is the forum in maintenance mode?
		if ($context['in_maintenance'] && $context['user']['is_admin'])
			echo '
								<b>', $txt[616], '</b><br />';

		// Are there any members waiting for approval?
		if (!empty($context['unapproved_members']))
			echo '
								', $context['unapproved_members'] == 1 ? $txt['approve_thereis'] : $txt['approve_thereare'], ' <a href="', $scripturl, '?action=viewmembers;sa=browse;type=approve">', $context['unapproved_members'] == 1 ? $txt['approve_member'] : $context['unapproved_members'] . ' ' . $txt['approve_members'], '</a> ', $txt['approve_members_waiting'], '<br />';

		// Show the total time logged in?
		if (!empty($context['user']['total_time_logged_in']))
		{
			echo '
								', $txt['totalTimeLogged1'];

			// If days is just zero, don't bother to show it.
			if ($context['user']['total_time_logged_in']['days'] > 0)
				echo $context['user']['total_time_logged_in']['days'] . $txt['totalTimeLogged2'];

			// Same with hours - only show it if it's above zero.
			if ($context['user']['total_time_logged_in']['hours'] > 0)
				echo $context['user']['total_time_logged_in']['hours'] . $txt['totalTimeLogged3'];

			// But, let's always show minutes - Time wasted here: 0 minutes ;).
			echo $context['user']['total_time_logged_in']['minutes'], $txt['totalTimeLogged4'], '<br />';
		}
		echo '				</span>';
	}
	// Otherwise they're a guest - this time ask them to either register or login - lazy bums...
	else
	{
		echo '				</span>
								<script language="JavaScript" type="text/javascript" src="', $settings['default_theme_url'], '/sha1.js"></script>

								<form action="', $scripturl, '?action=login2" method="post" accept-charset="', $context['character_set'], '" class="middletext" style="margin: 3px 1ex 1px 0;"', empty($context['disable_login_hashing']) ? ' onsubmit="hashLoginPassword(this, \'' . $context['session_id'] . '\');"' : '', '>
									<input type="text" name="user" size="10" /> <input type="password" name="passwrd" size="10" />
									<select name="cookielength">
										<option value="60">', $txt['smf53'], '</option>
										<option value="1440">', $txt['smf47'], '</option>
										<option value="10080">', $txt['smf48'], '</option>
										<option value="43200">', $txt['smf49'], '</option>
										<option value="-1" selected="selected">', $txt['smf50'], '</option>
									</select>
									<input type="submit" value="', $txt[34], '" /><br />
									<span class="middletext">', $txt['smf52'], '</span>
									<input type="hidden" name="hash_passwrd" value="" />
								</form>';
	}

	echo '
							</td>
						</tr>
					</table>
				</td>
			</tr>
		</table>';

	echo '
		<table id="upshrinkHeader2"', empty($options['collapse_header']) ? '' : ' style="display: none;"', ' width="100%" cellpadding="4" cellspacing="0" border="0">
			<tr>';

	// Show a random news item? (or you could pick one from news_lines...)
	if (!empty($settings['enable_news']))
		echo '
				<td width="90%" class="titlebg2">
					<span class="smalltext"><b>', $txt[102], '</b>: ', $context['random_news_line'], '</span>
				</td>';
	echo '
				<td class="titlebg2" align="right" nowrap="nowrap" valign="top">
					<form action="', $scripturl, '?action=search2" method="post" accept-charset="', $context['character_set'], '" style="margin: 0;">
						<a href="', $scripturl, '?action=search;advanced"><img src="'.$settings['images_url'].'/filter.gif" align="middle" style="margin: 0 1ex;" alt="" /></a>
						<input type="text" name="search" value="" style="width: 190px;" />&nbsp;
						<input type="submit" name="submit" value="', $txt[182], '" style="width: 11ex;" />
						<input type="hidden" name="advanced" value="0" />';

	// Search within current topic?
	if (!empty($context['current_topic']))
		echo '
						<input type="hidden" name="topic" value="', $context['current_topic'], '" />';

        // If we're on a certain board, limit it to this board ;).
	elseif (!empty($context['current_board']))
		echo '
						<input type="hidden" name="brd[', $context['current_board'], ']" value="', $context['current_board'], '" />';

	echo '
					</form>
				</td>
			</tr>
		</table>';

	// The main content should go here.
	echo '
	<div id="bodyarea" style="padding: 0ex 12px 0ex 12px;">';
}

function template_main_below()
{
	global $context, $settings, $options, $scripturl, $txt;

	echo '
	</div>';

	// Show the "Powered by" and "Valid" logos, as well as the copyright. Remember, the copyright must be somewhere!
	echo '

	<div id="footerarea" style="text-align: center; ', $context['browser']['needs_size_fix'] && !$context['browser']['is_ie6'] ? ' width: 100%;' : '', '">
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[
			function smfFooterHighlight(element, value)
			{
				element.src = smf_images_url + "/" + (value ? "h_" : "") + element.id + ".gif";
			}
		// ]]></script>
		<table cellspacing="0" cellpadding="3" border="0" style="border-top: 1px solid #000000; margin-top: 5px;" align="center" width="100%">
			<tr>
				<td valign="middle" align="center" style="white-space: nowrap;" class="smalltext">';
                    		// Show the load time?
                              	if ($context['show_load_time'])
                              	{
                                   echo '
                              		<span class="smalltext">', $txt['smf301'], $context['load_time'], $txt['smf302'], $context['load_queries'], $txt['smf302b'], '</span><br />';
                              	}
                                      echo'
        				', theme_copyright(), ' <br />';
                                        // THIS COPYRIGHT MUST REMAIN, UNLESS YOU CONTACT GAZMANAFC (GAZMANAFC@SIMPLEMACHINES.ORG) FOR COPYRIGHT REMOVAL OPTIONS
					echo'
                                        Around the World in 80 Settings Theme by <a href="http://multitalk2.com" target="_blank">MT2-Soft</a>, in association with <a href="http://smfthemes.org" target="_blank">SMFThemes</a> and <a href="http://tinyportalmedia.com" target="_blank">TinyPortal Media</a>. (Theme &copy; 2008, Gary M. Gadsdon)';
                                        // Have we set our own fourth line?
                                        echo'
                                        ' , !empty($settings['copyright']) ? '<br />' . $settings['copyright'] : '' , '
				</td>
			</tr>
		</table>';

	// This is an interesting bug in Internet Explorer AND Safari. Rather annoying, it makes overflows just not tall enough.
	if (($context['browser']['is_ie'] && !$context['browser']['is_ie4']) || $context['browser']['is_mac_ie'] || $context['browser']['is_safari'] || $context['browser']['is_firefox'])
	{
		// The purpose of this code is to fix the height of overflow: auto div blocks, because IE can't figure it out for itself.
		echo '
		<script language="JavaScript" type="text/javascript"><!-- // --><![CDATA[';

		// Unfortunately, Safari does not have a "getComputedStyle" implementation yet, so we have to just do it to code...
		if ($context['browser']['is_safari'])
			echo '
			window.addEventListener("load", smf_codeFix, false);

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if ((codeFix[i].className == "code" || codeFix[i].className == "post" || codeFix[i].className == "signature") && codeFix[i].offsetHeight < 20)
						codeFix[i].style.height = (codeFix[i].offsetHeight + 20) + "px";
				}
			}';
		elseif ($context['browser']['is_firefox'])
			echo '
			window.addEventListener("load", smf_codeFix, false);
			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = 0; i < codeFix.length; i++)
				{
					if (codeFix[i].className == "code" && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0))
						codeFix[i].style.overflow = "scroll";
				}
			}';			
		else
			echo '
			var window_oldOnload = window.onload;
			window.onload = smf_codeFix;

			function smf_codeFix()
			{
				var codeFix = document.getElementsByTagName ? document.getElementsByTagName("div") : document.all.tags("div");

				for (var i = codeFix.length - 1; i > 0; i--)
				{
					if (codeFix[i].currentStyle.overflow == "auto" && (codeFix[i].currentStyle.height == "" || codeFix[i].currentStyle.height == "auto") && (codeFix[i].scrollWidth > codeFix[i].clientWidth || codeFix[i].clientWidth == 0) && (codeFix[i].offsetHeight != 0 || codeFix[i].className == "code"))
						codeFix[i].style.height = (codeFix[i].offsetHeight + 36) + "px";
				}

				if (window_oldOnload)
				{
					window_oldOnload();
					window_oldOnload = null;
				}
			}';

		echo '
		// ]]></script>';
	}

	echo '
	</div>';

	// The following will be used to let the user know that some AJAX process is running
	echo '
	<div id="ajax_in_progress" style="display: none;', $context['browser']['is_ie'] && !$context['browser']['is_ie7'] ? 'position: absolute;' : '', '">', $txt['ajax_in_progress'], '</div>
</td>
  </tr>
</table></body></html>';
}

// Show a linktree. This is that thing that shows "My Community | General Category | General Discussion"..
function theme_linktree()
{
	global $context, $settings, $options;

	echo '<div class="nav" style="font-size: smaller; margin-bottom: 2ex; margin-top: 2ex;">';

	// Each tree item has a URL and name. Some may have extra_before and extra_after.
	foreach ($context['linktree'] as $link_num => $tree)
	{
		// Show something before the link?
		if (isset($tree['extra_before']))
			echo $tree['extra_before'];

		// Show the link, including a URL if it should have one.
		echo '<b>', $settings['linktree_link'] && isset($tree['url']) ? '<a href="' . $tree['url'] . '" class="nav">' . $tree['name'] . '</a>' : $tree['name'], '</b>';

		// Show something after the link...?
		if (isset($tree['extra_after']))
			echo $tree['extra_after'];

		// Don't show a separator for the last one.
		if ($link_num != count($context['linktree']) - 1)
			echo '&nbsp;' , !empty($settings['linktreecus']) ? $settings['linktreecus'] : '&gt;' , '&nbsp;';
	}

	echo '</div>';
}

// Show the menu up top. Something like [home] [help] [profile] [logout]...
function template_menu()
{
	global $context, $settings, $options, $scripturl, $txt;

	// Work out where we currently are.
	$current_action = 'home';
	if (in_array($context['current_action'], array('admin', 'managegames', 'arcadesettings', 'arcadecategory', 'ban', 'boardrecount', 'cleanperms', 'detailedversion', 'dumpdb', 'featuresettings', 'featuresettings2', 'findmember', 'maintain', 'manageattachments', 'manageboards', 'managecalendar', 'managesearch', 'membergroups', 'modlog', 'news', 'optimizetables', 'packageget', 'packages', 'permissions', 'pgdownload', 'postsettings', 'regcenter', 'repairboards', 'reports', 'serversettings', 'serversettings2', 'smileys', 'viewErrorLog', 'viewmembers')))
		$current_action = 'admin';
	if (in_array($context['current_action'], array('gallery','links','articles','staff', 'arcade', 'tag', 'contact', 'search', 'admin', 'calendar', 'profile', 'mlist', 'register', 'login', 'help', 'pm')))
		$current_action = $context['current_action'];
	if ($context['current_action'] == 'search2')
		$current_action = 'search';
	if ($context['current_action'] == 'theme')
		$current_action = isset($_REQUEST['sa']) && $_REQUEST['sa'] == 'pick' ? 'profile' : 'admin';

	// Are we using right-to-left orientation?
	if ($context['right_to_left'])
	{
		$first = 'last';
		$last = 'first';
	}
	else
	{
		$first = 'first';
		$last = 'last';
	}

// And away we go!
echo'
<table cellpadding="0" cellspacing="0" border="0">
   <tr>';
       
       // Home
       echo'
         <td valign="top" class="nav_' , $current_action == 'home' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
         <td valign="top" class="nav_' , $current_action == 'home' ? 'active_back' : 'back' , '">
             <a href="' , $scripturl , '">' , $txt[103] , '</a>
         </td><td class="' , $current_action == 'home' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
                       
       // Help
       echo'
         <td valign="top" class="nav_' , $current_action == 'help' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
         <td valign="top" class="nav_' , $current_action == 'help' ? 'active_back' : 'back' , '">
             <a href="' , $scripturl , '?action=help">' , $txt[119] , '</a>
         </td><td class="' , $current_action == 'help' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';

       // Search
       if ($context['allow_search'])
       {
         echo'
         <td valign="top" class="nav_' , $current_action == 'search' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
         <td valign="top" class="nav_' , $current_action == 'search' ? 'active_back' : 'back' , '">
             <a href="' , $scripturl , '?action=search">' , $txt[182] , '</a>
         </td><td class="' , $current_action == 'search' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
       }

       // Admin
       if ($context['allow_admin'])
       {
         echo'
         <td valign="top" class="nav_' , $current_action == 'admin' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
         <td valign="top" class="nav_' , $current_action == 'admin' ? 'active_back' : 'back' , '">
             <a href="' , $scripturl , '?action=admin"' , $settings['dropdown'] == 1 ? ' onclick="return clickreturnvalue()" onmouseover="dropdownmenu(this, event, \'admin\')"' : '' , '>
                ' , $txt[2] , '
             </a>';
               if ($settings['dropdown'] == 1)
               {
                 echo'
                 <div id="admin" class="anylinkcss" align="' , $context['right_to_left'] ? 'right' : 'left' , '" style="margin-bottom: 2px;">
                      <a href="' , $scripturl , '?action=admin">' , $txt['dpdwn_center'] , '</a>';
                 if(allowedTo('admin_forum'))
                   echo'
                      <a href="' , $scripturl , '?action=packages">' , $txt['dpdwn_package'] , '</a>
                      <a href="' , $scripturl , '?action=featuresettings">' , $txt['dpdwn_features'] , '</a>
                      <a href="' , $scripturl , '?action=serversettings;sesc=', $context['session_id'], '">' , $txt['dpdwn_server'] , '</a>
                      <a href="' , $scripturl , '?action=theme;sa=settings;th=', $settings['theme_id'], ';sesc=', $context['session_id'], '">' , $txt['dpdwn_current'] , '</a>
                      <a href="' , $scripturl , '?action=theme;sa=admin;sesc=', $context['session_id'], '">' , $txt['dpdwn_themes'] , '</a>';
                          if(allowedTo('manage_boards'))
                          echo'
                               <a href="' , $scripturl , '?action=manageboards">' , $txt['dpdwn_boards'] , '</a>';
                          if(allowedTo('manage_posts'))
                          echo'
                               <a href="' , $scripturl , '?action=postsettings">' , $txt['dpdwn_posts'] , '</a>';
                          if(allowedTo('admin_forum'))
                          echo'
                               <a href="' , $scripturl , '?action=managesearch">' , $txt[182] , '</a>';
                          if(allowedTo('manage_smileys'))
                          echo'
                               <a href="' , $scripturl , '?action=smileys">' , $txt['dpdwn_smilies'] , '</a>';
                          if(allowedTo('moderate_forum'))
                          echo'
                               <a href="' , $scripturl , '?action=viewmembers">' , $txt[331] , '</a>';
                          if(allowedTo('manage_membergroups'))
                          echo'
                               <a href="' , $scripturl , '?action=membergroups">' , $txt['dpdwn_membergroups'] , '</a>';
                          if(allowedTo('manage_bans'))
                          echo'
                               <a href="' , $scripturl , '?action=ban">' , $txt['dpdwn_banlist'] , '</a>';
                          if(allowedTo('admin_forum'))
                          echo'
                               <a href="' , $scripturl , '?action=maintain">' , $txt['dpdwn_maintain'] , '</a>
                               <a href="' , $scripturl , '?action=viewErrorLog;desc">' , $txt['dpdwn_errorlog'] , '</a>
                               <a href="' , $scripturl , '?action=modlog">' , $txt['dpdwn_modlog'] , '</a>';
                 echo'
                 </div>';
               }
               echo'
         </td><td class="' , $current_action == 'admin' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
       }

       // Profile
       if ($context['allow_edit_profile'])
       {
         echo'
         <td valign="top" class="nav_' , $current_action == 'profile' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
         <td valign="top" class="nav_' , $current_action == 'profile' ? 'active_back' : 'back' , '">
             <a href="' , $scripturl , '?action=profile"' , $settings['dropdown'] == 1 ? ' onclick="return clickreturnvalue()" onmouseover="dropdownmenu(this, event, \'profile\')"' : '' , '>
                ' , $txt[79] , '
             </a>';
               if($settings['dropdown'] == 1)
               {
                 echo'
                 <div id="profile" class="anylinkcss" align="' , $context['right_to_left'] ? 'right' : 'left' , '" style="margin-bottom: 2px;">';
                   if (allowedTo('profile_view_own'))
                     echo'
                     <a href="' , $scripturl , '?action=profile">' , $txt['dpdwn_summary'] , '</a>';
                        if (allowedTo('profile_identity_own'))
                        echo'
                             <a href="' , $scripturl , '?action=profile;sa=account">' , $txt['dpdwn_account'] , '</a>
                             <a href="' , $scripturl , '?action=profile;sa=forumProfile">' , $txt['dpdwn_profile'] , '</a>
                             <a href="' , $scripturl , '?action=profile;sa=theme">' , $txt['dpdwn_layout'] , '</a>
                             <a href="' , $scripturl , '?action=profile;sa=pmprefs">' , $txt['dpdwn_pmoptions'] , '</a>
                             <a href="' , $scripturl , '?action=profile;sa=notification">' , $txt['dpdwn_notifications'] , '</a>';
                        if (allowedTo('profile_view_own'))
                        echo'
                             <a href="' , $scripturl , '?action=profile;sa=statPanel">' , $txt['dpdwn_showstats'] , '</a>
                             <a href="' , $scripturl , '?action=profile;sa=showPosts">' , $txt['dpdwn_showposts'] , '</a>';
                        if ($context['user']['is_admin'])
                        echo'
                             <a href="' , $scripturl , '?action=profile;sa=trackUser">' , $txt['dpdwn_trackuser'] , '</a>
                             <a href="' , $scripturl , '?action=profile;sa=trackIP">' , $txt['dpdwn_trackip'] , '</a>';
                 echo'
                 </div>';
               }
               echo'
         </td><td class="' , $current_action == 'profile' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
         }

         // Messages
         if ($context['user']['is_logged'] && $context['allow_pm'])
         {
           echo'
           <td valign="top" class="nav_' , $current_action == 'pm' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
           <td valign="top" class="nav_' , $current_action == 'pm' ? 'active_back' : 'back' , '">
               <a href="' , $scripturl , '?action=pm"' , $settings['dropdown'] == 1 ? ' onclick="return clickreturnvalue()" onmouseover="dropdownmenu(this, event, \'pm\')"' : '' , '>
                  ' , $txt['pm_short'] , ' ', $context['user']['unread_messages'] > 0 ? '[<strong>'. $context['user']['unread_messages'] . '</strong>]' : '' , '
               </a>';
                 if($settings['dropdown'] == 1)
                 {
                   echo'
                   <div id="pm" class="anylinkcss" align="' , $context['right_to_left'] ? 'right' : 'left' , '" style="margin-bottom: 2px;">
                      <a href="' , $scripturl , '?action=pm">' , $txt['dpdwn_inbox'] , '</a>
                      <a href="' , $scripturl , '?action=pm;f=outbox">' , $txt['dpdwn_outbox'] , '</a>';
                         if (allowedTo('messagePost'))
                         echo'
                              <a href="' , $scripturl , '?action=pm;sa=send">' , $txt['dpdwn_sendnew'] , '</a>';
                   echo'
                   </div>';
                   }
                   echo'
           </td><td class="' , $current_action == 'pm' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
         }

               // Calendar
               if ($context['allow_calendar'])
               {
                 echo'
                       <td valign="top" class="nav_' , $current_action == 'calendar' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
                       <td valign="top" class="nav_' , $current_action == 'calendar' ? 'active_back' : 'back' , '" align="left">
                          <a href="' , $scripturl , '?action=calendar"' , $settings['dropdown'] == 1 ? ' onclick="return clickreturnvalue()" onmouseover="dropdownmenu(this, event, \'calendar\')"' : '' , '>
                             ' , $txt['calendar24'] , '
                          </a>';
                          if($settings['dropdown'] == 1)
                          {
                            echo'
                            <div id="calendar" class="anylinkcss" align="' , $context['right_to_left'] ? 'right' : 'left' , '" style="margin-bottom: 2px;">
                              <a href="' , $scripturl , '?action=calendar">' , $txt['dpdwn_viewcal'] , '</a>';
                                 if(allowedTo('calendar_post'))
                                 echo'
                                      <a href="' , $scripturl , '?action=calendar;sa=post">' , $txt['dpdwn_postevent'] , '</a>';
                            echo'
                            </div>';
                          }
                          echo'
                       </td><td class="' , $current_action == 'calendar' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
               }

               // Memberlist
               if ($context['allow_memberlist'])
               {
                 echo'
                       <td valign="top" class="nav_' , $current_action == 'mlist' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
                       <td valign="top" class="nav_' , $current_action == 'mlist' ? 'active_back' : 'back' , '">
                          <a href="' , $scripturl , '?action=mlist"' , $settings['dropdown'] == 1 ? ' onclick="return clickreturnvalue()" onmouseover="dropdownmenu(this, event, \'mlist\')"' : '' , '>
                             ' , $txt[331] , '
                          </a>';
                          if($settings['dropdown'] == 1)
                          {
                            echo'
                            <div id="mlist" class="anylinkcss" align="' , $context['right_to_left'] ? 'right' : 'left' , '" style="margin-bottom: 2px;">
                               <a href="' , $scripturl , '?action=mlist">' , $txt['dpdwn_viewmemlist'] , '</a>
                               <a href="' , $scripturl , '?action=mlist;sa=search">' , $txt['dpdwn_searchmemlist'] , '</a>
                            </div>';
                          }
                          echo'
                       </td><td class="' , $current_action == 'mlist' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
               }
               
               // Normal Kombat
               if(!empty($settings['arcade']))
               {
                 echo'
                       <td valign="top" class="nav_' , $current_action == 'arcade' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
                       <td valign="top" class="nav_' , $current_action == 'arcade' ? 'active_back' : 'back' , '">
				<a href="', $scripturl, '?action=arcade">' , $txt['arcade'] , '</a>
                       </td><td class="' , $current_action == 'arcade' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
               }
               
              // Gallery
              if(!empty($settings['gallery']))
              {
                 if ($context['allow_smfgallery_view'])
                    echo'
                       <td valign="top" class="nav_' , $current_action == 'gallery' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
                       <td valign="top" class="nav_' , $current_action == 'gallery' ? 'active_back' : 'back' , '">
                             <a href="', $scripturl, '?action=gallery">' , $txt['smfgallery_menu']  , '</a>
                       </td><td class="' , $current_action == 'gallery' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
              }

              // Articles
              if(!empty($settings['articles']))
              {
                 if ($context['allow_view_smfarticles'])
                    echo'
                       <td valign="top" class="nav_' , $current_action == 'articles' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
                       <td valign="top" class="nav_' , $current_action == 'articles' ? 'active_back' : 'back' , '">
                             <a href="', $scripturl, '?action=articles">' , $txt['smfarticles_menu']  , '</a>
                       </td><td class="' , $current_action == 'articles' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
              }

              // Tags
              if(!empty($settings['tags']))
              {
                    echo'
                       <td valign="top" class="nav_' , $current_action == 'tags' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
                       <td valign="top" class="nav_' , $current_action == 'tags' ? 'active_back' : 'back' , '">
                             <a href="', $scripturl, '?action=tags">' , $txt['smftags_menu']  , '</a>
                       </td><td class="' , $current_action == 'tags' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
              }

              // Links
              if(!empty($settings['links']))
              {
                 if ($context['allow_view_smflinks'])
                    echo'
                       <td valign="top" class="nav_' , $current_action == 'links' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
                       <td valign="top" class="nav_' , $current_action == 'links' ? 'active_back' : 'back' , '">
                             <a href="', $scripturl, '?action=tags">' , $txt['smflinks_menu']  , '</a>
                       </td><td class="' , $current_action == 'links' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
              }

              // Staff
              if(!empty($settings['staff']))
              {
                if ($context['allow_view_stafflist'])
                    echo'
                       <td valign="top" class="nav_' , $current_action == 'staff' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
                       <td valign="top" class="nav_' , $current_action == 'staff' ? 'active_back' : 'back' , '">
                             <a href="', $scripturl, '?action=staff">' , $txt['smfstaff_stafflist']  , '</a>
                       </td><td class="' , $current_action == 'staff' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
              }

              // Contact
              if(!empty($settings['contact']))
              {
                if ($context['allow_view_contact'])
                    echo'
                       <td valign="top" class="nav_' , $current_action == 'contact' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
                       <td valign="top" class="nav_' , $current_action == 'contact' ? 'active_back' : 'back' , '">
                             <a href="', $scripturl, '?action=contact">' , $txt['smfcontact_contact']  , '</a>
                       </td><td class="' , $current_action == 'contact' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
              }

               // Logout
               if($context['user']['is_logged'])
               {
                 echo'
                       <td valign="top" class="nav_' , $current_action == 'logout' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
                       <td valign="top" class="nav_' , $current_action == 'logout' ? 'active_back' : 'back' , '">
                           <a href="' , $scripturl , '?action=logout;sesc=', $context['session_id'], '">' , $txt[108] , '</a>
                       </td><td class="' , $current_action == 'logout' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
               }

               // Login
               if ($context['user']['is_guest'])
               {
                 echo'
                       <td valign="top" class="nav_' , $current_action == 'login' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
                       <td valign="top" class="nav_' , $current_action == 'login' ? 'active_back' : 'back' , '">
                           <a href="' , $scripturl , '?action=login">' , $txt[34] , '</a>
                       </td><td class="' , $current_action == 'login' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
               }

               // Register
               if($context['user']['is_guest'])
               {
                 echo'
                       <td valign="top" class="nav_' , $current_action == 'register' ? 'active_' . $first . '' : '' . $first . '' , '"></td>
                       <td valign="top" class="nav_' , $current_action == 'register' ? 'active_back' : 'back' , '">
                           <a href="' , $scripturl , '?action=register">' , $txt[97] , '</a>
                       </td><td class="' , $current_action == 'register' ? 'nav_active_' . $last . '' : 'nav_' . $last . '' , '"></td>';
               }

        // Country Form
        if ($settings['colour_toggle'] == 1 && $context['user']['is_logged'])
        {
   	   echo'
            <td>
               <form action="', $scripturl, '" style="margin: 0px;" method="post" class="smalltext">
                  <select name="options[theme_color]" onchange="this.form.submit();">
                      <option selected="selected" value="', $options['theme_color'], '">' , $txt['wonderful_animal'] , '</option>
                      <option value="england">' , $txt['eng'] , '</option>
                      <option value="scotland">' , $txt['sco'] , '</option>
                  </select>
                  <input alt="submit" type="submit" value="' , $txt['change'] , '" />
               </form>
            </td>';
        }

	// Endut Hoch Hech
	echo '
			</tr>
		</table>';
}

// Generate a strip of buttons.
function template_button_strip($button_strip, $direction = 'top', $force_reset = false, $custom_td = '')
{
	global $settings, $buttons, $context, $txt, $scripturl;

	// Create the buttons...
	foreach ($button_strip as $key => $value)
	{
		if (isset($value['test']) && empty($context[$value['test']]))
		{
			unset($button_strip[$key]);
			continue;
		}
		elseif (!isset($buttons[$key]) || $force_reset)
			$buttons[$key] = '<a href="' . $value['url'] . '" ' .( isset($value['custom']) ? $value['custom'] : '') . '>' . $txt[$value['text']] . '</a>';

		$button_strip[$key] = $buttons[$key];
	}

	if (empty($button_strip))
		return '<td>&nbsp;</td>';

	echo '
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_' , $context['right_to_left'] ? 'last' : 'first' , '">&nbsp;</td>
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_back">', implode(' &nbsp;|&nbsp; ', $button_strip) , '</td>
		<td class="', $direction == 'top' ? 'main' : 'mirror', 'tab_' , $context['right_to_left'] ? 'first' : 'last' , '">&nbsp;</td>';
}

?>